==> libnpupnp-2.2.1.tar.gz: libnpupnp-2.2.1/src/gena/client_table.cpp <==
/*******************************************************************************
 *
 * Copyright (c) 2000-2003 Intel Corporation 
 * All rights reserved. 
 * Copyright (c) 2012 France Telecom All rights reserved. 
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met: 
 *
 * - Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution. 
 * - Neither name of Intel Corporation nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY 
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/

#include "config.h"

#ifdef INCLUDE_CLIENT_APIS
#if EXCLUDE_GENA == 0

#include "client_table.h"

void RemoveClientSubClientSID(std::list<ClientSubscription>& lst,
							  const std::string& sid)
{
	for (auto it = lst.begin(); it != lst.end();) {
		if (it->SID == sid) {
			it = lst.erase(it);
		} else {
			it++;
		}
	}
}

ClientSubscription *GetClientSubClientSID(std::list<ClientSubscription>& lst,
										  const std::string& sid)
{
	for (auto& entry : lst) {
		if (entry.SID == sid) {
			return &entry;
		}
	}
	return nullptr;
}


ClientSubscription *GetClientSubActualSID(std::list<ClientSubscription>& lst,
										  const std::string& sid)
{
	for (auto& entry : lst) {
		if (entry.actualSID == sid) {
			return &entry;
		}
	}
	return nullptr;
}

#endif /* EXCLUDE_GENA */
#endif /* INCLUDE_CLIENT_APIS */

==> libnpupnp-4.0.5.tar.gz: libnpupnp-4.0.5/src/gena/client_table.cpp <==
/*******************************************************************************
 *
 * Copyright (c) 2000-2003 Intel Corporation 
 * All rights reserved. 
 * Copyright (c) 2012 France Telecom All rights reserved. 
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met: 
 *
 * - Redistributions of source code must retain the above copyright notice, 
 * this list of conditions and the following disclaimer. 
 * - Redistributions in binary form must reproduce the above copyright notice, 
 * this list of conditions and the following disclaimer in the documentation 
 * and/or other materials provided with the distribution. 
 * - Neither name of Intel Corporation nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL INTEL OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY 
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/

#include "config.h"

#ifdef INCLUDE_CLIENT_APIS
#if EXCLUDE_GENA == 0

#include "client_table.h"

#include <algorithm>

void RemoveClientSubClientSID(std::list<ClientSubscription>& lst,
							  const std::string& sid)
{
	for (auto it = lst.begin(); it != lst.end();) {
		if (it->SID == sid) {
			it = lst.erase(it);
		} else {
			it++;
		}
	}
}

ClientSubscription *GetClientSubClientSID(
	std::list<ClientSubscription>& lst, const std::string& sid)
{
	if (lst.empty()) {
		return nullptr;
	}
	auto i = std::find_if(lst.begin(), lst.end(),
						  [&](const ClientSubscription &entry) {
							  return entry.SID == sid;});
	return i == lst.end() ? nullptr : &(*i);
}

#include <iostream>

ClientSubscription *GetClientSubActualSID(
	std::list<ClientSubscription>& lst, const std::string& sid)
{
	if (lst.empty()) {
		return nullptr;
	}
	auto i = std::find_if(lst.begin(), lst.end(),
						  [&](const ClientSubscription &entry) {
							  return entry.actualSID == sid;});
	return i == lst.end() ? nullptr : &(*i);
}

#endif /* EXCLUDE_GENA */
#endif /* INCLUDE_CLIENT_APIS */
